==> haskell-uri-bytestring-aeson-0.1.0.9-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-4v6QA62V60lH7oudfev9IY
key:                  uri-bytestring-aeson-0.1.0.9-4v6QA62V60lH7oudfev9IY
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  856702dcdca305d5dca2fca75cae9440
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.2.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-4v6QA62V60lH7oudfev9IY
depends:
    aeson-2.1.2.1-FhTjbzRVW7jFzXz0ecy3pa base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0
    uri-bytestring-0.3.3.1-GzGMY7c1mRX5baihRHOhMG

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-aeson-0.1.0.9-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 uri-bytestring-aeson
version:              0.1.0.9
visibility:           public
id:                   uri-bytestring-aeson-0.1.0.9-K6VxnQoC3sRGQScQIJNMic
key:                  uri-bytestring-aeson-0.1.0.9-K6VxnQoC3sRGQScQIJNMic
license:              BSD-3-Clause
maintainer:           hafnersimon@gmail.com
author:               Simon Hafner
homepage:             https://github.com/reactormonk/uri-bytestring-aeson
synopsis:             Aeson instances for URI Bytestring
category:             URI
abi:                  36040e0e328d52777678692194bda7ae
exposed:              True
exposed-modules:      URI.ByteString.Aeson
import-dirs:          /usr/lib/ghc-9.2.8/site-local/uri-bytestring-aeson-0.1.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/uri-bytestring-aeson-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring-aeson
hs-libraries:         HSuri-bytestring-aeson-0.1.0.9-K6VxnQoC3sRGQScQIJNMic
depends:
    aeson-2.1.2.1-EcnOkqJy6qkFyx4PSoTHhT base-4.16.4.0
    bytestring-0.11.4.0 text-1.2.5.0
    uri-bytestring-0.3.3.1-4HEK7gId4D5KRKy4neVzML

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring-aeson/html/uri-bytestring-aeson.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
